==> msxpertsuite_5.0.2.orig.tar.gz: msxpertsuite-5.0.2/massxpert/nongui/ChemEntVignetteRenderer.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */




#ifndef CHEM_ENT_VIGNETTE_RENDERER_HPP
#define CHEM_ENT_VIGNETTE_RENDERER_HPP


/////////////////////// Qt includes
#include <QSvgRenderer>


namespace msXpSmassXpert
{

  class ChemEntVignetteRenderer : public QSvgRenderer
  {
    Q_OBJECT

    private:
    int m_refCount;
    QHash<QString, ChemEntVignetteRenderer *> *mp_hash;

    public:
    ChemEntVignetteRenderer(QObject * = 0,
                            QHash<QString, ChemEntVignetteRenderer *> * = 0);

    ChemEntVignetteRenderer(const QString &, QObject *                  = 0,
                            QHash<QString, ChemEntVignetteRenderer *> * = 0);

    ChemEntVignetteRenderer(const QByteArray &, QObject *               = 0,
                            QHash<QString, ChemEntVignetteRenderer *> * = 0);


    ~ChemEntVignetteRenderer();

    void setHash(QHash<QString, ChemEntVignetteRenderer *> *);
    void setRefCount(int);
    int  refCount();
    void incrementRefCount();
    void decrementRefCount();
  };

} // namespace msXpSmassXpert


#endif // CHEM_ENT_VIGNETTE_RENDERER_HPP

==> msxpertsuite_5.8.5.orig.tar.gz: msxpertsuite-5.8.5/massxpert/nongui/ChemEntVignetteRenderer.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef CHEM_ENT_VIGNETTE_RENDERER_HPP
#define CHEM_ENT_VIGNETTE_RENDERER_HPP


/////////////////////// Qt includes
#include <QSvgRenderer>


namespace msXpSmassXpert
{

class ChemEntVignetteRenderer : public QSvgRenderer
{
  Q_OBJECT

  private:
  int m_refCount;
  QHash<QString, ChemEntVignetteRenderer *> *mp_hash;

  public:
  ChemEntVignetteRenderer(QObject *                                   = 0,
                          QHash<QString, ChemEntVignetteRenderer *> * = 0);

  ChemEntVignetteRenderer(const QString &,
                          QObject *                                   = 0,
                          QHash<QString, ChemEntVignetteRenderer *> * = 0);

  ChemEntVignetteRenderer(const QByteArray &,
                          QObject *                                   = 0,
                          QHash<QString, ChemEntVignetteRenderer *> * = 0);


  ~ChemEntVignetteRenderer();

  void setHash(QHash<QString, ChemEntVignetteRenderer *> *);
  void setRefCount(int);
  int refCount();
  void incrementRefCount();
  void decrementRefCount();
};

} // namespace msXpSmassXpert


#endif // CHEM_ENT_VIGNETTE_RENDERER_HPP
